==> haskell-libmpd-0.9.0.8-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-5OuOAoJIxJxLckDT6eymUf
key: libmpd-0.9.0.8-5OuOAoJIxJxLckDT6eymUf
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 48946aef66df633f11c176ae905f5ab8
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.6.3/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.6.3/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-5OuOAoJIxJxLckDT6eymUf
depends:
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 filepath-1.4.2.1
    mtl-2.2.2 network-2.7.0.2-LBw9vnb0Msk5Ad9gKMihTx
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libmpd-0.9.0.8-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libmpd.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libmpd
version: 0.9.0.8
id: libmpd-0.9.0.8-AmDnrCBqz7eFdyKIHWlrXu
key: libmpd-0.9.0.8-AmDnrCBqz7eFdyKIHWlrXu
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
author: Ben Sinclair
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
abi: 0f5c030675dae3becdb33d587efaa6bf
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
import-dirs: /usr/lib/ghc-8.6.3/site-local/libmpd-0.9.0.8
library-dirs: /usr/lib/ghc-8.6.3/site-local/libmpd-0.9.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/libmpd-0.9.0.8
hs-libraries: HSlibmpd-0.9.0.8-AmDnrCBqz7eFdyKIHWlrXu
depends:
    attoparsec-0.13.2.2-Jk4D4QRG8ZrHQCpZMillSF base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 filepath-1.4.2.1
    mtl-2.2.2 network-2.8.0.0-Gkz8D69XrP78tYGHTDKPK9
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-libmpd/html/libmpd.haddock
haddock-html: /usr/share/doc/haskell-libmpd/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
